@@ -58,12 +58,6 @@ fn get_sentences(
     if json_ld.len() > 0 {
         result.insert("json_ld".to_string(), json_ld);
     }
-
-    let rel_alternate = get_rel_alternate(&document);
-    if rel_alternate.len() > 0 {
-        result.insert("rel_alternate".to_string(), rel_alternate);
-    }
-
     for tag in REMOVE_TAGS {
         remove_tag(&document, tag);
     }
@@ -173,6 +167,12 @@ fn get_emails(html: String) -> PyResult<Vec<String>> {
     Ok(links.collect::<Vec<String>>())
 }
 
+#[pyfunction]
+fn get_alternate_links(html: String) -> PyResult<HashMap<String, String>> {
+    let document = kuchiki::parse_html().one(html);
+    Ok(get_rel_alternate(&document))
+}
+
 #[pyfunction]
 fn html_contents(html: String) -> PyResult<String> {
     let document = kuchiki::parse_html().one(html);
@@ -221,17 +221,17 @@ fn get_json_ld(document: &NodeRef) -> Vec<String> {
     return result;
 }
 
-fn get_rel_alternate(document: &NodeRef) -> Vec<String> {
-    let mut result: Vec<String> = Vec::new();
+fn get_rel_alternate(document: &NodeRef) -> HashMap<String, String> {
+    let mut result: HashMap<String, String> = HashMap::new();
     let tag_nodes = document.select("link").unwrap();
     for tag_node in tag_nodes.collect::<Vec<_>>() {
         let attributes = tag_node.attributes.borrow();
         let type_attribute = attributes.get("rel").unwrap_or("");
         if type_attribute == "alternate" {
-            let mut value = attributes.get("hreflang").unwrap_or("").to_string();
-            value.push_str(":");
-            value.push_str(attributes.get("href").unwrap_or(""));
-            result.push(value);
+            result.insert(
+                attributes.get("hreflang").unwrap_or("").to_string(),
+                attributes.get("href").unwrap_or("").to_string(),
+            );
         }
     }
     return result;
@@ -297,6 +297,7 @@ fn html_parsing_tools(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(tag_html_contents, m)?)?;
     m.add_function(wrap_pyfunction!(get_sentences, m)?)?;
     m.add_function(wrap_pyfunction!(get_href_attributes, m)?)?;
+    m.add_function(wrap_pyfunction!(get_alternate_links, m)?)?;
     Ok(())
 }
 
